@@ -2,7 +2,8 @@
 # This file is released as part of leetscraper under GPL-2.0 License.
 # Find this project at https://github.com/Pavocracy/leetscraper
 
-"""leetscraper, a coding challenge webscraper for leetcode, and other websites!"""
+"""leetscraper, a coding challenge webscraper for leetcode, and other
+websites!"""
 
 __licence__ = "GPL-2.0"
 __author__ = "Pavocracy"
