@@ -2,9 +2,8 @@
 # This file is released as part of leetscraper under GPL-2.0 License.
 # Find this project at https://github.com/Pavocracy/leetscraper
 
-"""leetscraper currently supports codechef.com, codewars.com, hackerrank.com, leetcode.com,
-projecteuler.net.
-"""
+"""leetscraper currently supports codechef.com, codewars.com, hackerrank.com,
+leetcode.com, projecteuler.net."""
 
 __all__ = ["Codechef", "Codewars", "Hackerrank", "Leetcode", "Projecteuler"]
 
